@@ -23,6 +23,8 @@ async def listen_ws(ws):
     async for msg in ws:
         if msg.tp == aiohttp.MsgType.text:
             sys.stdout.write("%s" % msg.data)
+        if msg.tp == aiohttp.MsgType.binary:
+            sys.stdout.write("%s" % str(msg.data))
         elif msg.tp == aiohttp.MsgType.closed:
             print(msg)
             sys.exit(1)
